@@ -27,7 +27,7 @@ from concurrent import futures
 from diskcache import Cache
 from requests_futures.sessions import FuturesSession
 from scipy import ndimage
-from tqdm.auto import trange
+from tqdm.auto import trange, tqdm
 
 from .. import spine
 from .. import xform
@@ -63,16 +63,10 @@ def fetch_leaderboard(days=7, by_day=False, progress=True, max_threads=4):
     Examples
     --------
     >>> from fafbseg import flywire
-    >>> # Fetch leaderboard
-    >>> edits = flywire.fetch_edit_history(720575940621039145)
-    >>> # Group by user
-    >>> edits.groupby('user_name').size()
-    user_name
-    Claire McKellar    47
-    Jay Gager           4
-    Sandeep Kumar       1
-    Sarah Morejohn      6
-    dtype: int64
+    >>> # Fetch leaderboard with edits per day
+    >>> hist = flywire.fetch_leaderboard(by_day=True)
+    >>> # Plot user actions over time
+    >>> hist.T.plot()
 
     """
     assert isinstance(days, (int, np.int))
@@ -319,26 +313,31 @@ def supervoxels_to_roots(x, timestamp=None, batch_size=10_000,
     # Prepare results array
     roots = np.zeros(x.shape, dtype=np.int64)
 
-    if isinstance(timestamp. np.datetime64):
+    if isinstance(timestamp, np.datetime64):
         timestamp = str(timestamp)
 
-    for i in trange(0, len(x), int(batch_size),
-                    desc='Fetching roots',
-                    disable=not progress or len(x) < batch_size):
-        # This batch
-        batch = x[i:i+batch_size]
+    with tqdm(desc='Fetching roots',
+              leave=False,
+              total=len(x),
+              disable=not progress or len(x) < batch_size) as pbar:
 
-        # get_roots() doesn't like to be asked for zeros - causes server error
-        not_zero = batch != 0
-        try:
-            roots[i:i+batch_size][not_zero] = vol.get_roots(batch[not_zero],
-                                                            timestamp=timestamp)
-        except BaseException:
-            if not retry:
-                raise
-            time.sleep(1)
-            roots[i:i+batch_size][not_zero] = vol.get_roots(batch[not_zero],
-                                                            timestamp=timestamp)
+        for i in range(0, len(x), int(batch_size)):
+            # This batch
+            batch = x[i:i+batch_size]
+
+            # get_roots() doesn't like to be asked for zeros - causes server error
+            not_zero = batch != 0
+            try:
+                roots[i:i+batch_size][not_zero] = vol.get_roots(batch[not_zero],
+                                                                timestamp=timestamp)
+            except BaseException:
+                if not retry:
+                    raise
+                time.sleep(1)
+                roots[i:i+batch_size][not_zero] = vol.get_roots(batch[not_zero],
+                                                                timestamp=timestamp)
+
+            pbar.update(len(batch))
 
     return roots
 
@@ -394,7 +393,7 @@ def locs_to_supervoxels(locs, mip=2, coordinates='voxel'):
                                       coordinates=coordinates, mip=-1)
 
 
-def neuron_to_segments(x, dataset='production', coordinates='voxel'):
+def neuron_to_segments(x, short=False, dataset='production', coordinates='voxel'):
     """Get root IDs overlapping with a given neuron.
 
     Parameters
@@ -402,6 +401,9 @@ def neuron_to_segments(x, dataset='production', coordinates='voxel'):
     x :                 Neuron/List
                         Neurons for which to return root IDs. Neurons must be
                         in flywire (FAFB14.1) space.
+    short :             bool
+                        If True will only return the top hit for each neuron
+                        (including a confidence score).
     dataset :           str | CloudVolume
                         Against which flywire dataset to query::
                             - "production" (current production dataset, fly_v31)
@@ -422,6 +424,13 @@ def neuron_to_segments(x, dataset='production', coordinates='voxel'):
                             10336680915   5     0
                             10336682132   0     1
 
+    summary :           pandas.DataFrame
+                        If ``short=True``: DataFrame of top hits only::
+
+                            id            match   confidence
+                            12345   103366809155     0.87665
+                            412314  103366821325     0.65233
+
     """
     if isinstance(x, navis.TreeNeuron):
         x = navis.NeuronList(x)
@@ -447,7 +456,23 @@ def neuron_to_segments(x, dataset='production', coordinates='voxel'):
     # and values are the overlap counts
     matrix = seg_counts.pivot(index='root_id', columns='id', values='counts')
 
-    return matrix
+    if not short:
+        return matrix
+
+    # Extract top IDs and scores
+    top_id = matrix.index[np.argmax(matrix.fillna(0).values, axis=0)]
+
+    # Confidence is the difference between top and 2nd score
+    top_score = matrix.max(axis=0).values
+    sec_score = np.sort(matrix.fillna(0).values, axis=0)[-2, :]
+    conf = (top_score - sec_score) / matrix.sum(axis=0).values
+
+    summary = pd.DataFrame([])
+    summary['id'] = matrix.columns
+    summary['match'] = top_id
+    summary['confidence'] = conf
+
+    return summary
 
 
 def locs_to_segments(locs, root_ids=True, timestamp=None, dataset='production',
@@ -660,12 +685,12 @@ def update_ids(id,
     Parameters
     ----------
     id :            int | list-like
-                    Single ID or list of flywire (root) IDs.
+                    Single ID or list of FlyWire (root) IDs.
     sample :        int | float
                     Number (>= 1) or fraction (< 1) of super voxels to sample
                     to guess the most recent version.
     dataset :       str | CloudVolume
-                    Against which flywire dataset to query:
+                    Against which FlyWire dataset to query:
                       - "production" (current production dataset, fly_v31)
                       - "sandbox" (i.e. fly_v26)
     progress :      bool
@@ -713,6 +738,12 @@ def update_ids(id,
                                                                         disable=not progress or len(id) == 1)]
         return pd.concat(res, axis=0, sort=False, ignore_index=True)
 
+    try:
+        id = int(id)
+    except ValueError:
+        raise ValueError(f'{id} does not look like a valid root ID.')
+
+
     # Check if outdated
     if isinstance(is_latest, type(None)):
         is_latest = is_latest_root(id, dataset=dataset)[0]
