@@ -18,6 +18,7 @@ import navis
 import requests
 import warnings
 
+import cloudvolume as cv
 import numpy as np
 import pandas as pd
 import trimesh as tm
@@ -92,7 +93,7 @@ class SpineService(ABC):
         """Return general info on given service."""
         if not hasattr(self, '_info'):
             url = self.makeurl('info')
-            resp = requests.get(url)
+            resp = self.session.get(url)
             resp.raise_for_status()
             self._info = resp.json()
         return self._info
@@ -110,6 +111,95 @@ class SpineService(ABC):
         return self.urljoin(self.base_url, *args)
 
 
+class FlyCacheService(SpineService):
+    """Interface with cache services."""
+
+    def __init__(self,
+                 base_url='https://services.itanna.io/app/flycache-dev'):
+        """Init class."""
+        self.base_url = base_url
+
+    def get_L2_centroids(self, ids, token, as_array=False, chunksize=50,
+                         progress=True):
+        """Fetch centroids of given l2 chunks.
+
+        Coordinates are in nm.
+
+        Parameter
+        ---------
+        ids :           iterable
+                        Iterable with L2 IDs.
+        token :         str
+                        A ChunkedGraph/CAVE auth token.
+        as_array :      bool
+                        Determines output (see Returns).
+        chunksize :     int
+                        Query L2 IDs in chunks of this size.
+        progress :      bool
+                        Whether to show a progress bar or not.
+
+        Returns
+        -------
+        array
+                        If `as_array=True`: array in same order as queried `ids`.
+                        Missing centroids are returns with coordinate (0, 0, 0).
+        dict
+                        If `as_array=False`: dictionary mapping ID to
+                        centroid `{L2_ID: [x, y, z], ..}`.
+
+        """
+        url = self.makeurl('mesh/l2_centroid/flywire_fafb_production/')
+
+        # Make sure we have an array of integers
+        ids = navis.utils.make_iterable(ids).astype(int)
+
+        with navis.config.tqdm(total=len(ids), desc='Fetching centroids',
+                               leave=False, disable=not progress) as pbar:
+
+            # First we will get everything that's cached in a single big query
+            post = {
+                      "token": token,
+                      "query_ids": ids.tolist()
+                    }
+            resp = self.session.post(url + '?cache_only=1', json=post)
+            resp.raise_for_status()
+
+            # Parse response
+            centroids = {int(k): v for k, v in resp.json().items()}
+
+            # Filter to remaining IDs
+            to_fetch = ids[~np.isin(ids, list(centroids))]
+
+            # Update progress bar
+            pbar.update(len(centroids))
+
+            # Now go over the remaining indices in chunks
+            for i in range(0, len(to_fetch), int(chunksize)):
+                this_chunk = to_fetch[i:i+chunksize]
+                post = {
+                          "token": token,
+                          "query_ids": this_chunk.tolist()
+                        }
+
+                resp = self.session.post(url, json=post)
+                resp.raise_for_status()
+
+                # Parse response
+                data = resp.json()
+
+                # IDs will have been returned as strings
+                centroids.update({int(k): v for k, v in data.items()})
+
+                pbar.update(len(this_chunk))
+
+        if not as_array:
+            return centroids
+
+        centroids = np.array([centroids.get(i, [0, 0, 0]) for i in ids])
+
+        return centroids
+
+
 class SynapseService(SpineService):
     """Interface with synapse service on `spine.janelia.org`.
 
@@ -128,13 +218,14 @@ class SynapseService(SpineService):
                  base_url='https://spine.janelia.org/app/synapse-service'):
         """Init class."""
         self.base_url = base_url
+        self.session = requests.Session()
 
     @property
     def alignments(self):
         """Return available alignments of synapse data."""
         if not hasattr(self, '_alignments'):
             url = self.makeurl('alignments')
-            resp = requests.get(url)
+            resp = self.session.get(url)
             resp.raise_for_status()
             self._alignments = resp.json()
         return self._alignments
@@ -144,7 +235,7 @@ class SynapseService(SpineService):
         """Return available collections of synapse data."""
         if not hasattr(self, '_collections'):
             url = self.makeurl('collections')
-            resp = requests.get(url)
+            resp = self.session.get(url)
             resp.raise_for_status()
             self._collections = resp.json()
         return self._collections
@@ -154,7 +245,7 @@ class SynapseService(SpineService):
         """Return available segmentations the synapse data is mapped to."""
         if not hasattr(self, '_segmentations'):
             url = self.makeurl('segmentations')
-            resp = requests.get(url)
+            resp = self.session.get(url)
             resp.raise_for_status()
             self._segmentations = resp.json()
         return self._segmentations
@@ -203,7 +294,7 @@ class SynapseService(SpineService):
         self.validate_collection(collection)
 
         url = self.makeurl('collection', collection, 'synapse', synapse_id, 'info')
-        resp = requests.get(url)
+        resp = self.session.get(url)
         resp.raise_for_status()
         return resp.json()
 
@@ -252,7 +343,7 @@ class SynapseService(SpineService):
 
         post = {"query_ids": segmentation_ids.tolist()}
 
-        resp = requests.post(url, json=post)
+        resp = self.session.post(url, json=post)
         resp.raise_for_status()
 
         # Read into DataFrame
@@ -290,6 +381,7 @@ class TransformService(SpineService):
                  base_url='https://spine.janelia.org/app/transform-service'):
         """Init class."""
         self.base_url = base_url
+        self.session = requests.Session()
 
     def validate_dataset(self, dataset):
         """Check if dataset exists for given service."""
@@ -423,7 +515,7 @@ class TransformService(SpineService):
             this_vxl = vxl[ix: ix + limit_request]
 
             # Make request
-            resp = requests.post(url,
+            resp = self.session.post(url,
                                  data=this_vxl.astype(np.single).tobytes(order='C'))
 
             # Check for errors
@@ -498,7 +590,7 @@ class TransformService(SpineService):
             this_vxl = vxl[ix: ix + limit_request]
 
             # Make request
-            resp = requests.post(url,
+            resp = self.session.post(url,
                                  data=this_vxl.astype(np.single).tobytes(order='C'))
 
             # Check for errors
@@ -653,3 +745,4 @@ def query_spine_transform(x, dataset, query, coordinates='nm', mip=2,
 
 synapses = SynapseService()
 transform = TransformService()
+flycache = FlyCacheService()
